
__description__ = 'BgoKit, A tool package for Bgolearn'
__documents__ = 'https://bgolearn.netlify.app/'
__author__ = 'Bin Cao, Advanced Materials Thrust, Hong Kong University of Science and Technology (Guangzhou)'
__author_email__ = 'binjacobcao@gmail.com'
__url__ = 'https://github.com/Bin-Cao/Bgolearn'
